#
# spec file for package libgig
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover_gig  11
%define sover_akai 0
Name:           libgig
Version:        4.4.1
Release:        1.3
Summary:        Library for loading Gigasampler and DLS Level 1/2 files
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://linuxsampler.org/
Source0:        http://download.linuxsampler.org/packages/libgig-%{version}.tar.bz2
BuildRequires:  c++_compiler
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sndfile) >= 1.0.2
BuildRequires:  pkgconfig(uuid)

%description
C++ library for loading Gigasampler and DLS Level 1/2 files.

%package -n libgig%{sover_gig}
Summary:        Library for loading Gigasampler and DLS Level 1/2 files
Group:          System/Libraries

%description -n libgig%{sover_gig}
C++ library for loading Gigasampler and DLS Level 1/2 files.

%package -n libakai%{sover_akai}
Summary:        Library for accessing AKAI disk images
Group:          System/Libraries

%description -n libakai%{sover_akai}
C++ library for accessing AKAI disk images

%package -n libgig-devel
Summary:        Library for loading Gigasampler and DLS Level 1/2 files
Group:          Development/Languages/C and C++
Requires:       libgig%{sover_gig} = %{version}

%description -n libgig-devel
C++ library for loading Gigasampler and DLS Level 1/2 files.

%package -n libgig-tools
Summary:        Example applications for libgig
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       libgig%{sover_gig} = %{version}-%{release}
Provides:       libgig6-tools = %{version}-%{release}
Obsoletes:      libgig6-tools < %{version}

%description -n libgig-tools
Some example applications for the libgig package.

* gigdump: demo app that prints out the content of a .gig file
* gigextract: extracts samples from a .gig file
* dlsdump: demo app that prints out the content of a DLS file
* rifftree: tool that prints out the RIFF tree of an arbitrary RIFF file

%prep
%autosetup -p1

%build
%configure --disable-static
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d/
echo "%{_libdir}/libgig"  > "%{buildroot}%{_sysconfdir}/ld.so.conf.d/libgig%{sover_gig}.conf"
echo "%{_libdir}/libakai" > "%{buildroot}%{_sysconfdir}/ld.so.conf.d/libakai%{sover_akai}.conf"

%check
%make_build check

%ldconfig_scriptlets -n libgig%{sover_gig}
%ldconfig_scriptlets -n libakai%{sover_akai}

%files -n libgig%{sover_gig}
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%dir %{_libdir}/libgig/
%{_libdir}/libgig/libgig.so.%{sover_gig}
%{_libdir}/libgig/libgig.so.%{sover_gig}.*
%config %{_sysconfdir}/ld.so.conf.d/libgig%{sover_gig}.conf

%files -n libakai%{sover_akai}
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%{_libdir}/libgig/libakai.so.%{sover_akai}
%{_libdir}/libgig/libakai.so.%{sover_akai}.*
%config %{_sysconfdir}/ld.so.conf.d/libakai%{sover_akai}.conf

%files -n libgig-devel
%license COPYING
%dir %{_libdir}/libgig/
%{_libdir}/libgig/*.so
%{_includedir}/libgig/
%{_libdir}/pkgconfig/*.pc

%files -n libgig-tools
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}

%changelog
* Tue Apr 23 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to version 4.4.1:
  * Fix build errors with some compilers
- drop unused rpmlintrc
* Sat Jan 27 2024 Edgar Aichinger <edogawa@aon.at>
- update to version 4.4.0 (libgig.so.11):
  * add new command line tool "wav2gig"
  * see libgig's ChangeLog for a list of source and API changes
* Tue May 18 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to version 4.3.0 (libgig.so.10):
  * requires a C++11 compliant compiler
  * gig file format extensions used by recent versions of
    LinuxSampler
  * Fix compatibility with GigaStudio 3
  * Extend Serialization framework o support common C++ STL classes
* Fri Oct 18 2019 Edgar Aichinger <edogawa@aon.at>
- Update to version 4.2.0
  new libgig soversion
  use %%license for COPYING
* Wed Feb 21 2018 olaf@aepfle.de
- Update to version 4.1.0
  CVE-2017-12950, CVE-2017-12951, CVE-2017-12952, CVE-2017-12953,
  CVE-2017-12954, bsc#1056143
- Split libakai.so.0 from devel pkg
* Tue Mar 28 2017 olaf@aepfle.de
- ExclusiveArch Intel
* Sun Feb 12 2017 olaf@aepfle.de
- Update to version 4.0.0
* Mon Sep  5 2016 edogawa@aon.at
- removed version strings from date/email lines in libgig.changes
- ran spec-cleaner on libgig.spec
* Fri Sep  2 2016 edogawa@aon.at
- fixed crippled mail addresses in libgig.changes
* Thu Aug 11 2016 jengelh@inai.de
- Correction of RPM groups, abolish old macros and %%clean section.
  Rename soname macro to sover because there was no name in it.
* Fri Feb 19 2016 edogawa@aon.at
- split out changelog into separate .changes file
* Wed Dec 17 2014 giordanoboschetti@gmail.com
- update to svn trunk rev 2680
* Mon Apr 16 2012 pascal.bleser@opensuse.org
- update to svn trunk rev 2342
* Sat Feb 27 2010 toni@links2linux.de
- update to 3.3.0
* Fri Dec  7 2007 toni@links2linux.de
- update to 3.2.1
* Mon Oct 15 2007 toni@links2linux.de
- update to 3.2.0
* Sun Oct 14 2007 toni@links2linux.de
- update to 3.2.0-cvs20071014
* Sun Oct  7 2007 toni@links2linux.de
- update to 3.1.1-cvs20071006
* Tue Oct  2 2007 toni@links2linux.de
- update to 3.1.1-cvs20071001
* Tue Sep 11 2007 toni@links2linux.de
- update to 3.1.1-cvs20070910
* Fri Aug  3 2007 toni@links2linux.de
- update to 3.1.1-cvs20070802
* Fri Jul  6 2007 toni@links2linux.de
- update to 3.1.1-cvs20070622
* Sun Jun  3 2007 toni@links2linux.de
- update to 3.1.1-cvs20070601
- changed package-layout according new Shared Library Packaging Policy
* Sat May 26 2007 toni@links2linux.de
- update to 3.1.1-cvs20070525
* Sun May 13 2007 toni@links2linux.de
- update to 3.1.1-cvs20070513
* Mon Apr 16 2007 toni@links2linux.de
- update to 3.1.1-cvs20070413
* Sat Mar 24 2007 toni@links2linux.de
- update to 3.1.1-cvs20070324
* Wed Nov 29 2006 toni@links2linux.de
- update to 3.1.0-final
* Fri Nov 24 2006 toni@links2linux.de
- update to 3.1.0-cvs20061124
* Mon Oct 30 2006 toni@links2linux.de
- update to 3.0.0-cvs20061030
* Thu Oct 26 2006 toni@links2linux.de
- update to 3.0.0-cvs20061026
* Fri Oct 20 2006 toni@links2linux.de
- update to 3.0.0-cvs20061019
* Mon Sep 18 2006 toni@links2linux.de
- build for packman
* Sat Sep  2 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060902
* Sun Aug 20 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060820
* Fri Aug 11 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060811
* Sat Jul 22 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060722
* Thu Jun  1 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060601
* Sun May 14 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060514
* Sat May  6 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060506
* Sun Apr 30 2006 oc2pus@arcor.de 
- update to 3.0.0
* Fri Mar  3 2006 oc2pus@arcor.de 
- update to cvs20060303
* Mon Dec 26 2005 oc2pus@arcor.de 
- update to cvs20051226
* Thu Dec 22 2005 oc2pus@arcor.de 
- update to cvs20051222
* Fri Nov 25 2005 oc2pus@arcor.de 
- update to cvs20051125
* Tue Nov 22 2005 oc2pus@arcor.de 
- update to cvs20051122
* Thu Nov 17 2005 oc2pus@arcor.de 
- update to cvs20051117
* Sat Nov 12 2005 oc2pus@arcor.de 
- update to cvs20051112
* Fri Nov  4 2005 oc2pus@arcor.de 
- update to cvs20051104
* Mon Sep 26 2005 oc2pus@arcor.de 
- update to cvs20050917
* Sat Sep 17 2005 oc2pus@arcor.de 
- update to cvs20050917
- changes in spec-file for build on x86_64
* Wed Aug 17 2005 oc2pus@arcor.de 
- update to cvs20050816
* Tue Aug  2 2005 oc2pus@arcor.de 
- update to cvs20050726
* Mon Jul 18 2005 oc2pus@arcor.de 
- update to cvs20050718
* Sun Jun 19 2005 oc2pus@arcor.de 
- update to cvs20050619
* Mon Jun 13 2005 oc2pus@arcor.de 
- update to cvs20050613
* Tue Jun  7 2005 oc2pus@arcor.de 
- update to cvs20050607
* Mon Jun  6 2005 oc2pus@arcor.de 
- update to cvs20050606
* Wed May 18 2005 oc2pus@arcor.de 
- update to cvs20050518
* Mon May  9 2005 oc2pus@arcor.de 
- update to cvs20050509
- removed Patch
* Sun May  8 2005 oc2pus@arcor.de 
- update to cvs20050508
- included Patch for VERSION/PACKAGE
* Thu May  5 2005 oc2pus@arcor.de 
- update to cvs20050505
* Tue May  3 2005 oc2pus@arcor.de 
- update to cvs20050503
- added audiofile to Requires/BuildRequires
* Mon Mar  7 2005 oc2pus@arcor.de 
- build for SuSE
- little modifications using RPM-macros
* Wed Nov 24 2004 rncbc@users.sourceforge.net
- prepared for 1.0.0
* Sat Jul 10 2004 cuse@users.sourceforge.net
- renamed 'libgig.pc' to 'gig.pc' as well as the pkg-config lib name
* Fri Jul  2 2004 rncbc@users.sourceforge.net
- Created and corrected initial libgig.spec
